summaryrefslogtreecommitdiffstats
path: root/libkcal/vcalformat.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
commit7be55ffa061c026e35e2d6a0effe1161ddb0d41f (patch)
tree8474f9b444b2756228600050f07a7ff25de532b2 /libkcal/vcalformat.h
parentf587f20a6d09f1729dd0a8c1cd8ee0110aec7451 (diff)
downloadtdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.tar.gz
tdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1157655 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkcal/vcalformat.h')
-rw-r--r--libkcal/vcalformat.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/libkcal/vcalformat.h b/libkcal/vcalformat.h
index 039ecfc2..cb51f417 100644
--- a/libkcal/vcalformat.h
+++ b/libkcal/vcalformat.h
@@ -54,7 +54,7 @@ class LIBKCAL_EXPORT VCalFormat : public CalFormat
@param fileName Name of the vCalendar file on disk.
@return true on success, otherwise false
*/
- bool load( Calendar *calendar, const QString &fileName );
+ bool load( Calendar *calendar, const TQString &fileName );
/**
Writes out the given calendar to disk in vCalendar format.
@@ -62,16 +62,16 @@ class LIBKCAL_EXPORT VCalFormat : public CalFormat
@param fileName the name of the file
@return true on success, otherwise false
*/
- bool save(Calendar *calendar, const QString &fileName);
+ bool save(Calendar *calendar, const TQString &fileName);
/**
Parse string and populate calendar with that information.
*/
- bool fromString( Calendar *, const QString & );
+ bool fromString( Calendar *, const TQString & );
/**
Return calendar information as string.
*/
- QString toString( Calendar * );
+ TQString toString( Calendar * );
protected:
/** translates a VObject of the TODO type into a Event */
@@ -83,16 +83,16 @@ class LIBKCAL_EXPORT VCalFormat : public CalFormat
/** translate a Event into a VObject and returns a pointer to it. */
VObject* eventToVEvent(const Event *anEvent);
- /** takes a QDate and returns a string in the format YYYYMMDDTHHMMSS */
- QString qDateToISO(const QDate &);
- /** takes a QDateTime and returns a string in format YYYYMMDDTHHMMSS */
- QString qDateTimeToISO(const QDateTime &, bool zulu=TRUE);
+ /** takes a TQDate and returns a string in the format YYYYMMDDTHHMMSS */
+ TQString qDateToISO(const TQDate &);
+ /** takes a TQDateTime and returns a string in format YYYYMMDDTHHMMSS */
+ TQString qDateTimeToISO(const TQDateTime &, bool zulu=TRUE);
/** takes a string in the format YYYYMMDDTHHMMSS and returns a
- * valid QDateTime. */
- QDateTime ISOToQDateTime(const QString & dtStr);
+ * valid TQDateTime. */
+ TQDateTime ISOToQDateTime(const TQString & dtStr);
/** takes a string in the format YYYYMMDD and returns a
- * valid QDate. */
- QDate ISOToQDate(const QString & dtStr);
+ * valid TQDate. */
+ TQDate ISOToQDate(const TQString & dtStr);
/** takes a vCalendar tree of VObjects, and puts all of them that have
* the "event" property into the dictionary, todos in the todo-list, etc. */
void populate(VObject *vcal);
@@ -101,10 +101,10 @@ class LIBKCAL_EXPORT VCalFormat : public CalFormat
* i.e. MO, TU, WE, etc. */
const char *dayFromNum(int day);
/** the reverse of the above function. */
- int numFromDay(const QString &day);
+ int numFromDay(const TQString &day);
Attendee::PartStat readStatus(const char *s) const;
- QCString writeStatus(Attendee::PartStat status) const;
+ TQCString writeStatus(Attendee::PartStat status) const;
private:
Calendar *mCalendar;